@@ -1,79 +1,78 @@
 package Fey::Loader::SQLite;
-
-use strict;
-use warnings;
-
-our $VERSION = '0.11';
+BEGIN {
+  $Fey::Loader::SQLite::VERSION = '0.12';
+}
 
 use Moose;
 
-extends 'Fey::Loader::DBI';
+use namespace::autoclean;
 
 use DBD::SQLite 1.20;
 
+extends 'Fey::Loader::DBI';
 
-package # hide from PAUSE
+package    # hide from PAUSE
     DBD::SQLite::Fixup;
 
-BEGIN
-{
-    unless ( defined &DBD::SQLite::db::column_info )
-    {
+BEGIN {
+    unless ( defined &DBD::SQLite::db::column_info ) {
         *DBD::SQLite::db::column_info = \&_sqlite_column_info;
     }
 
-    unless ( defined &DBD::SQLite::db::statistics_info )
-    {
+    unless ( defined &DBD::SQLite::db::statistics_info ) {
         *DBD::SQLite::db::statistics_info = \&_sqlite_statistics_info;
     }
 }
 
 sub _sqlite_statistics_info {
-    my($dbh, $catalog, $schema, $table, $unique_only) = @_;
+    my ( $dbh, $catalog, $schema, $table, $unique_only ) = @_;
 
-    my @names = qw( TABLE_CAT TABLE_SCHEM TABLE_NAME NON_UNIQUE INDEX_QUALIFIER
-                    INDEX_NAME TYPE ORDINAL_POSITION COLUMN_NAME COLLATION
-                    CARDINALITY PAGES FILTER_CONDITION
-                 );
+    my @names
+        = qw( TABLE_CAT TABLE_SCHEM TABLE_NAME NON_UNIQUE INDEX_QUALIFIER
+        INDEX_NAME TYPE ORDINAL_POSITION COLUMN_NAME COLLATION
+        CARDINALITY PAGES FILTER_CONDITION
+    );
 
-    my $sth_indexes = $dbh->prepare( qq{PRAGMA index_list('$table')} );
+    my $sth_indexes = $dbh->prepare(qq{PRAGMA index_list('$table')});
     $sth_indexes->execute;
 
     my @indexes;
     for my $index ( @{ $sth_indexes->fetchall_arrayref } ) {
-        next if $unique_only && ! $index->[2];
+        next if $unique_only && !$index->[2];
 
-        my $sth_index_info = $dbh->prepare( qq{PRAGMA index_info('$index->[1]')} );
+        my $sth_index_info
+            = $dbh->prepare(qq{PRAGMA index_info('$index->[1]')});
         $sth_index_info->execute;
 
         for my $index_part ( @{ $sth_index_info->fetchall_arrayref } ) {
             my %index;
 
-            $index{TABLE_NAME} = $table;
-            $index{NON_UNIQUE} = $index->[2] ? 0 : 1;
-            $index{INDEX_NAME} = $index->[1];
+            $index{TABLE_NAME}       = $table;
+            $index{NON_UNIQUE}       = $index->[2] ? 0 : 1;
+            $index{INDEX_NAME}       = $index->[1];
             $index{ORDINAL_POSITION} = $index_part->[1] + 1;
-            $index{COLUMN_NAME} = $index_part->[2];
+            $index{COLUMN_NAME}      = $index_part->[2];
 
             push @indexes, \%index;
         }
     }
 
-    my $sponge = DBI->connect("DBI:Sponge:", '','')
-        or return $dbh->DBI::set_err($DBI::err, "DBI::Sponge: $DBI::errstr");
-    my $sth = $sponge->prepare("statistics_info $table", {
-        rows => [ map { [ @{$_}{@names} ] } @indexes ],
-        NUM_OF_FIELDS => scalar @names,
-        NAME => \@names,
-    }) or return $dbh->DBI::set_err($sponge->err(), $sponge->errstr());
+    my $sponge = DBI->connect( "DBI:Sponge:", '', '' )
+        or
+        return $dbh->DBI::set_err( $DBI::err, "DBI::Sponge: $DBI::errstr" );
+    my $sth = $sponge->prepare(
+        "statistics_info $table", {
+            rows          => [ map { [ @{$_}{@names} ] } @indexes ],
+            NUM_OF_FIELDS => scalar @names,
+            NAME          => \@names,
+        }
+    ) or return $dbh->DBI::set_err( $sponge->err(), $sponge->errstr() );
     return $sth;
 }
 
-
 package Fey::Loader::SQLite;
 
-sub _add_table
-{
+sub _add_table {
     my $self       = shift;
     my $schema     = shift;
     my $table_info = shift;
@@ -83,8 +82,7 @@ sub _add_table
     $self->SUPER::_add_table( $schema, $table_info );
 }
 
-sub _is_auto_increment
-{
+sub _is_auto_increment {
     my $self     = shift;
     my $table    = shift;
     my $col_info = shift;
@@ -104,8 +102,7 @@ sub _is_auto_increment
     return $sql =~ /autoincrement/mi ? 1 : 0;
 }
 
-sub _primary_key
-{
+sub _primary_key {
     my $self = shift;
     my $name = shift;
 
@@ -118,45 +115,49 @@ sub _primary_key
     return @pk;
 }
 
-sub _table_sql
-{
+sub _table_sql {
     my $self = shift;
     my $name = shift;
 
     return $self->{__table_sql__}{$name}
         if $self->{__table_sql__}{$name};
 
-    return $self->{__table_sql__}{$name} =
-        $self->dbh()->selectcol_arrayref
-            ( 'SELECT sql FROM sqlite_master WHERE tbl_name = ?', {}, $name )->[0];
+    return $self->{__table_sql__}{$name}
+        = $self->dbh()
+        ->selectcol_arrayref(
+        'SELECT sql FROM sqlite_master WHERE tbl_name = ?', {}, $name )->[0];
 }
 
-sub _default
-{
+sub _default {
     my $self    = shift;
     my $default = shift;
 
-    if ( $default =~ /CURRENT_(?:TIME(?:STAMP)?|DATE)/i )
-    {
+    if ( $default =~ /CURRENT_(?:TIME(?:STAMP)?|DATE)/i ) {
         return Fey::Literal::Term->new($default);
     }
-    else
-    {
+    else {
         return $self->SUPER::_default($default);
     }
 }
 
-no Moose;
 __PACKAGE__->meta()->make_immutable();
 
 1;
 
-__END__
+# ABSTRACT: Loader for SQLite schemas
+
+
+
+=pod
 
 =head1 NAME
 
 Fey::Loader::SQLite - Loader for SQLite schemas
 
+=head1 VERSION
+
+version 0.12
+
 =head1 SYNOPSIS
 
   my $loader = Fey::Loader->new( dbh => $dbh );
@@ -172,10 +173,6 @@ behavior.
 
 This class provides the same public methods as L<Fey::Loader::DBI>.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 BUGS
 
 Please report any bugs or feature requests to
@@ -183,11 +180,20 @@ C<bug-fey-loader@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2006-2008 Dave Rolsky, All Rights Reserved.
+Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2011 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
+
+
+__END__
+
